@@ -532,6 +532,7 @@ var bamCmd = &cobra.Command{
 		execAfter := getFlagString(cmd, "exec-after")
 		printTop := getFlagString(cmd, "top-bam")
 		topSize := getFlagInt(cmd, "top-size")
+		toolYaml := getFlagString(cmd, "tool")
 		includeIdList := getFlagString(cmd, "grep-ids")
 		excludeIdList := getFlagString(cmd, "exclude-ids")
 
@@ -561,6 +562,18 @@ var bamCmd = &cobra.Command{
 			os.Exit(0)
 		}
 
+		if toolYaml != "" {
+			if toolYaml == "help" && len(toolYaml) == 0 {
+				files = []string{"-"}
+
+			}
+			if len(files) != 1 {
+				log.Fatal("The BAM toolbox takes exactly one input file!")
+			}
+			BamToolbox(toolYaml, files[0], outFile, printQuiet, silentMode, config.Threads)
+			os.Exit(0)
+		}
+
 		if printBundle != 0 {
 			if len(files) != 1 {
 				log.Fatal("The BAM bundler takes exactly one input file!")
@@ -650,18 +663,6 @@ var bamCmd = &cobra.Command{
 		}
 		_ = getRightSoftClip
 
-		getHardClipped := func(r *sam.Record) float64 {
-			var hc float64
-			last := len(r.Cigar) - 1
-			if r.Cigar[last].Type() == sam.CigarHardClipped {
-				hc += float64(r.Cigar[last].Len())
-			}
-			if r.Cigar[0].Type() == sam.CigarHardClipped {
-				hc += float64(r.Cigar[0].Len())
-			}
-			return hc
-		}
-
 		getRead := func(r *sam.Record) string {
 			return r.Name
 		}
@@ -679,63 +680,14 @@ var bamCmd = &cobra.Command{
 
 		fmap["Acc"] = fieldInfo{
 			"Alignment accuracy",
-			func(r *sam.Record) float64 {
-				var mismatch int
-				aux, ok := r.Tag([]byte("NM"))
-				if !ok {
-					panic("no NM tag")
-				}
-				var mm int
-				var ins int
-				var del int
-				var skip int
-				switch aux.Value().(type) {
-				case int:
-					mismatch = int(aux.Value().(int))
-				case int8:
-					mismatch = int(aux.Value().(int8))
-				case int16:
-					mismatch = int(aux.Value().(int16))
-				case int32:
-					mismatch = int(aux.Value().(int32))
-				case int64:
-					mismatch = int(aux.Value().(int64))
-				case uint:
-					mismatch = int(aux.Value().(uint))
-				case uint8:
-					mismatch = int(aux.Value().(uint8))
-				case uint16:
-					mismatch = int(aux.Value().(uint16))
-				case uint32:
-					mismatch = int(aux.Value().(uint32))
-				case uint64:
-					mismatch = int(aux.Value().(uint64))
-				default:
-					panic("Could not parse NM tag: " + aux.String())
-				}
-				for _, op := range r.Cigar {
-					switch op.Type() {
-					case sam.CigarMatch, sam.CigarEqual, sam.CigarMismatch:
-						mm += op.Len()
-					case sam.CigarInsertion:
-						ins += op.Len()
-					case sam.CigarDeletion:
-						del += op.Len()
-					case sam.CigarSkipped:
-						skip += op.Len()
-					default:
-						//fmt.Println(op)
-					}
-				}
-				return (1.0 - float64(mismatch)/float64(mm+ins+del)) * 100
-			},
+			GetSamAcc,
 		}
 
 		fmap["ReadLen"] = fieldInfo{
 			"Read length",
 			func(r *sam.Record) float64 {
 				if r.Seq.Length > 0 {
-					sl := float64(r.Seq.Length) + getHardClipped(r)
+					sl := float64(r.Seq.Length) + float64(GetSamHardClipped(r))
 					return float64(sl)
 				}
 				var ql int
@@ -1294,7 +1246,6 @@ func init() {
 
 	bamCmd.Flags().IntP("map-qual", "q", 0, "minimum mapping quality")
 	bamCmd.Flags().StringP("field", "f", "", "target fields")
-	//bamCmd.Flags().StringP("scatter", "S", "", "scatter plot of two numerical fields")
 	bamCmd.Flags().StringP("img", "O", "", "save histogram to this PDF/image file")
 	bamCmd.Flags().IntP("print-freq", "p", -1, "print/report after this many records (-1 for print after EOF)")
 	bamCmd.Flags().IntP("delay", "W", 1, "sleep this many seconds after plotting")
@@ -1307,6 +1258,7 @@ func init() {
 	bamCmd.Flags().BoolP("idx-stat", "i", false, "fast statistics based on the BAM index")
 	bamCmd.Flags().BoolP("idx-count", "C", false, "fast read per reference counting based on the BAM index")
 	bamCmd.Flags().StringP("count", "c", "", "count reads per reference and save to this file")
+	bamCmd.Flags().StringP("tool", "T", "", "invoke toolbox in YAML format (see documentation)")
 	bamCmd.Flags().BoolP("log", "L", false, "log10(x+1) transform numeric values")
 	bamCmd.Flags().BoolP("reset", "R", false, "reset histogram after every report")
 	bamCmd.Flags().BoolP("pass", "x", false, "passthrough mode (forward filtered BAM to output)")
